@@ -94,7 +94,7 @@ airsis_EBAMQualityControl <- function(tbl,
   badRows <- !(goodLonMask & goodLatMask)
   badRowCount <- sum(badRows)
   if ( badRowCount > 0 ) {
-    logger.info(paste(verb,"%s rows with invalid location information"), badRowCount)
+    logger.debug(paste(verb,"%s rows with invalid location information"), badRowCount)
     badLocations <- paste('(',tbl$Longitude[badRows],',',tbl$Latitude[badRows],')',sep='')
     logger.debug("Bad locations: %s", paste0(badLocations, collapse=", "))
     if ( flagAndKeep ) {
@@ -110,6 +110,13 @@ airsis_EBAMQualityControl <- function(tbl,
 
   tbl <- tbl[goodLonMask & goodLatMask,]
   
+  # Sanity check -- row count
+  if ( nrow(tbl) < 1 && !flagAndKeep ) {
+    err_msg <- paste0("No valid PM2.5 data for ", monitorName)
+    logger.warn(err_msg) # This is more of a warning than some error in the data.
+    stop(err_msg, call.=FALSE)
+  }
+  
   # ----- Time ----------------------------------------------------------------
   
   # Add a POSIXct datetime
@@ -137,7 +144,7 @@ airsis_EBAMQualityControl <- function(tbl,
   badRows <- !goodTypeMask
   badRowCount <- sum(badRows)
   if ( badRowCount > 0 ) {
-    logger.info(paste(verb,"%s rows with invalid Type information"), badRowCount)
+    logger.debug(paste(verb,"%s rows with invalid Type information"), badRowCount)
     logger.debug("Bad Types:  %s", paste0(sort(unique(tbl$Type[badRows]),na.last=TRUE), collapse=", "))
     if ( flagAndKeep ) {
       # apply flags
@@ -150,8 +157,11 @@ airsis_EBAMQualityControl <- function(tbl,
 
   tbl <- tbl[goodTypeMask,]
   
-  if (nrow(tbl) < 1) {
-    logger.warn("No valid PM2.5 data for %s", monitorName)
+  # Sanity check -- row count
+  if ( nrow(tbl) < 1 && !flagAndKeep ) {
+    err_msg <- paste0("No valid PM2.5 data for ", monitorName)
+    logger.warn(err_msg) # This is more of a warning than some error in the data.
+    stop(err_msg, call.=FALSE)
   }
   
   # Leland Tarnay QC -----------------------------------------------------------
@@ -191,7 +201,7 @@ airsis_EBAMQualityControl <- function(tbl,
   badQCCount <- sum(!goodMask)
   
   if ( badQCCount > 0 ) {
-    logger.info(paste(verb,"%s rows because of QC logic"), badQCCount)
+    logger.debug(paste(verb,"%s rows because of QC logic"), badQCCount)
     if ( flagAndKeep ) {
       # apply flags
       tblFlagged$QCFlag_badFlow[tbl$rowID[!goodFlow]] <- TRUE
@@ -212,6 +222,13 @@ airsis_EBAMQualityControl <- function(tbl,
   
   tbl <- tbl[goodMask,]
   
+  # Sanity check -- row count
+  if ( nrow(tbl) < 1 && !flagAndKeep ) {
+    err_msg <- paste0("No valid PM2.5 data for ", monitorName)
+    logger.warn(err_msg) # This is more of a warning than some error in the data.
+    stop(err_msg, call.=FALSE)
+  }
+  
   # ----- Duplicate Hours -----------------------------------------------------
   
   # For hours with multiple records, discard all but the one with the latest processing date/time
@@ -224,7 +241,7 @@ airsis_EBAMQualityControl <- function(tbl,
   uniqueHrMask <- !dupHrMask
   
   if ( dupHrCount > 0 ) {
-    logger.info(paste(verb,"%s duplicate time entries"), dupHrCount)
+    logger.debug(paste(verb,"%s duplicate time entries"), dupHrCount)
     logger.debug("Duplicate Hours (may be >1 per timestamp):  %s", paste0(sort(unique(tbl$Date.Time.GMT[dupHrMask])), collapse=", "))
     if ( flagAndKeep ) {
       # apply flags
@@ -237,6 +254,13 @@ airsis_EBAMQualityControl <- function(tbl,
   
   tbl <- tbl[uniqueHrMask,]
   
+  # Sanity check -- row count
+  if ( nrow(tbl) < 1 && !flagAndKeep ) {
+    err_msg <- paste0("No valid PM2.5 data for ", monitorName)
+    logger.warn(err_msg) # This is more of a warning than some error in the data.
+    stop(err_msg, call.=FALSE)
+  }
+  
   # ----- More QC -------------------------------------------------------------
   
   # NOTE:  Additional QC would go here
