@@ -36,7 +36,7 @@
 monitorPlot_dailyBarplot <- function(ws_monitor,
                                      monitorID=NULL,
                                      tlim=NULL,
-                                     minHours=20,
+                                     minHours=18,
                                      gridPos='',
                                      gridCol='black',
                                      gridLwd=0.5,
@@ -44,7 +44,12 @@ monitorPlot_dailyBarplot <- function(ws_monitor,
                                      labels_x_nudge=0,
                                      labels_y_nudge=0,
                                      ...) {
- 
+
+  # Sanity check
+  if ( monitor_isEmpty(ws_monitor) ) {
+    stop("ws_monitor object contains zero monitors")
+  }
+    
   # Data Preparation ----------------------------------------------------------
   
   # Allow single monitor objects to be used without specifying monitorID
