@@ -8,7 +8,7 @@
 #' and renames the \code{'datetime'} column so that it can be processed by the \pkg{openair} package's
 #' \code{timeAverage()} function. (See that function for details.)
 #' @examples
-#' C_V <- monitor_subset(CarmelValley, tlim=c(2016080800,2016081023),
+#' C_V <- monitor_subset(Carmel_Valley, tlim=c(2016080800,2016081023),
 #'                       timezone='America/Los_Angeles')
 #' C_V_3hourly <- monitor_timeAverage(C_V, avg.time="3 hour")
 #' head(C_V$data, n=15)
@@ -17,6 +17,9 @@
 
 monitor_timeAverage <- function(ws_monitor, ...) {
   
+  # Sanity check
+  if ( monitor_isEmpty(ws_monitor) ) stop("ws_monitor object contains zero monitors")
+  
   # Extract and prepare data
   meta <- ws_monitor$meta
   data <- ws_monitor$data
